@@ -1,23 +1,17 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-import grab
 from TechParser import parser
+import feedparser
 
 def get_articles(reddits=['tech']):
-	g = grab.Grab()
-	parser.setup_grab(g)
-	
-	css_path = 'div.entry p.title a.title'
-	
 	articles = []
 	links = []
 	
 	for r in reddits:
-		g.go('http://www.reddit.com/r/%s' %r)
-		
-		for article in parser.get_articles(g, css_path, css_path,
-			'reddit', 'www.reddit.com'):
+		parsed = parser.get_articles_from_rss(
+			'http://www.reddit.com/r/{}/.rss'.format(r), 'reddit')
+		for article in parsed:
 			if article['link'] not in links:
 				links.append(article['link'])
 				articles.append(article)
